@@ -1,10 +1,8 @@
 """Metadata for the Project."""
 
-from __future__ import annotations
-
 from importlib.metadata import PackageNotFoundError, metadata, version
 
-__all__ = ["__project__", "__version__"]
+__all__ = ("__project__", "__version__")
 
 try:
     __version__ = version("sqlspec")
