@@ -1,20 +1,22 @@
 from contextlib import contextmanager
-from dataclasses import dataclass
+from dataclasses import dataclass, field
+from sqlite3 import Connection
 from typing import TYPE_CHECKING, Any, Literal, Optional, Union
 
+from sqlspec.adapters.sqlite.driver import SqliteDriver
 from sqlspec.base import NoPoolSyncConfig
 from sqlspec.exceptions import ImproperConfigurationError
 from sqlspec.typing import Empty, EmptyType, dataclass_to_dict
 
 if TYPE_CHECKING:
     from collections.abc import Generator
-    from sqlite3 import Connection
 
-__all__ = ("SqliteConfig",)
+
+__all__ = ("Sqlite",)
 
 
 @dataclass
-class SqliteConfig(NoPoolSyncConfig["Connection"]):
+class Sqlite(NoPoolSyncConfig["Connection", "SqliteDriver"]):
     """Configuration for SQLite database connections.
 
     This class provides configuration options for SQLite database connections, wrapping all parameters
@@ -46,6 +48,10 @@ class SqliteConfig(NoPoolSyncConfig["Connection"]):
 
     uri: "Union[bool, EmptyType]" = Empty
     """If set to True, database is interpreted as a URI with supported options."""
+    driver_type: "type[SqliteDriver]" = field(init=False, default_factory=lambda: SqliteDriver)
+    """Type of the driver object"""
+    connection_type: "type[Connection]" = field(init=False, default_factory=lambda: Connection)
+    """Type of the connection object"""
 
     @property
     def connection_config_dict(self) -> "dict[str, Any]":
@@ -54,7 +60,9 @@ class SqliteConfig(NoPoolSyncConfig["Connection"]):
         Returns:
             A string keyed dict of config kwargs for the sqlite3.connect() function.
         """
-        return dataclass_to_dict(self, exclude_empty=True, convert_nested=False)
+        return dataclass_to_dict(
+            self, exclude_empty=True, convert_nested=False, exclude={"pool_instance", "driver_type", "connection_type"}
+        )
 
     def create_connection(self) -> "Connection":
         """Create and return a new database connection.
@@ -80,11 +88,21 @@ class SqliteConfig(NoPoolSyncConfig["Connection"]):
         Yields:
             A SQLite connection instance.
 
-        Raises:
-            ImproperConfigurationError: If the connection could not be established.
         """
         connection = self.create_connection()
         try:
             yield connection
         finally:
             connection.close()
+
+    @contextmanager
+    def provide_session(self, *args: Any, **kwargs: Any) -> "Generator[SqliteDriver, None, None]":
+        """Create and provide a database connection.
+
+        Yields:
+            A DuckDB driver instance.
+
+
+        """
+        with self.provide_connection(*args, **kwargs) as connection:
+            yield self.driver_type(connection)
